@@ -33,13 +33,18 @@ private slots:
     void on_btnSearch_clicked();
     void on_btnDownload_clicked();
     void download(QString item);
+    void stream(QString item);
     void downloadFinished(QNetworkReply *reply);
+    void streamFinished(QNetworkReply *reply);
 
     void on_actionAbout_triggered();
 
+    void on_btnPlay_clicked();
+
 private:
     Ui::MainWindow *ui;
     QNetworkAccessManager *netAccessMan;
+    QNetworkAccessManager *netAccessManStream;
     QByteArray downloadedItem;
     QStringList *links;
     QMovie *movie;
